# File generated from our OpenAPI spec by Stainless. See CONTRIBUTING.md for details.

from typing import List
from typing_extensions import TypeAlias

from .individual import Individual

__all__ = ["IndividualListResponse"]

IndividualListResponse: TypeAlias = List[Individual]
